/**
  * @file current_executable.hpp
  * @brief Параметры исполняемового файла
  */

#ifndef MYX_FILESYSTEM_CURRENT_EXECUTABLE_HPP_
#define MYX_FILESYSTEM_CURRENT_EXECUTABLE_HPP_

#include <QString>
#include <QDir>
#include <QFileInfo>

namespace myx {

namespace filesystem {

class CurrentExecutable
{
	/// Путь к символической ссылке, указывающей на текущий исполняемый файл
	QFileInfo m_procFilePath;
	/// Канонический путь к текущему исполняемому файлу
	QFileInfo m_canonicalFilePath;
	/// Канонический путь к каталогу с текущим исполняемым файлом
	QDir m_canonicalPath;
	/// Имя текущего исполняемого файла
	QString m_fileName;

public:
	/**
	 * @brief Конструктор, собирающий информацию о текущем исполняемом файле.
	 *        Иницализируются все внутренние переменные.
	 */
	CurrentExecutable();
	/**
	 * @brief Канонический путь к текущему исполняемому файлу
	 */
	QFileInfo canonicalFilePath() const;
	/**
	 * @brief Канонический путь к каталогу с текущим исполняемым файлом
	 */
	QDir canonicalPath() const;
	/**
	 * @brief Имя текущего исполняемого файла
	 */
	QString fileName() const;
}; // class CurrentExecutable

} // namespace filesystem

} // namespace myx

#endif // MYX_FILESYSTEM_CURRENT_EXECUTABLE_HPP_
